'****************************************************************************
' Z80-Melodieklingel aus dem FA 4/86 S.203 mit AMTEL-AVR AT90S4433
' uwe@felgentreu.com (2003)
'****************************************************************************

$regfile = "4433def.dat"      ' AT90S4433-Deklarationen
Const Quarz = 11059200        ' Quarz: 11.059.200 MHz
$crystal = Quarz

Const Pre = 1                 ' kein Vorteiler

Config Timer0 = Timer , Prescale = 1       ' ergibt 43,2 kHz
On Ovf0 Tim0_isr              ' Define the ISR handler

Config Timer1 = Timer , Prescale = Pre
On Ovf1 Tim1_isr              ' Define the ISR handler
Enable Timer1

On Int0 Isr_int0              ' externen Interrupt 0 freigeben
Config Int0 = Rising          ' Interrupt bei H/L-Flanke
Enable Int0                   ' INT0 ein

On Int1 Isr_int1              ' externen Interrupt 1 freigeben
Config Int1 = Rising          ' Interrupt bei H/L-Flanke
Enable Int1                   ' INT1 ein

Const Reload = Int(quarz /((65535 * Pre) * 10))
                              ' Teiler um mit Timer1 auf 100ms-INT zu kommen
Enable Interrupts             ' Interrupts freigeben

Config Watchdog = 2048        ' Reset nach 2048 mSec
Start Watchdog                ' Start Watchdog Timer

'****************************************************************************
Const Tabende = 255           ' Kennzeichen fr Tabellenende
Const Liedende = 128          ' Kennzeichen fr Liedende
Const Sperrdauer = 40         ' Wartezeit fr Klingelsperre
'****************************************************************************
Led_stop Alias Portc.1        ' LED STOP
Led_play Alias Portc.3        ' LED Wiedergabe
Led_takt Alias Portc.4        ' LED Takt
Led_sperre Alias Portc.2      ' LED Sperre aktiv
Speaker Alias Portc.5         ' Tonausgang
'****************************************************************************
Startup:
'****************************************************************************
Ddrb = &B000000               ' alles Eingang (nicht in Nutzung)
Ddrd = &B0000_0000            ' alles Eingang (nicht in Nutzung)
Ddrc = &B111110               ' alles Ausgang ausser .0
Portb = &B111111              ' alle PullUP ein
Portd = &B1111_1111           ' alle PullUP ein
Portc = &B111111              ' alle PullUP und Ausgnge ein
'****************************************************************************
'Variablen
Dim Sperre As Byte            ' Sperrcounter
Dim Scounter As Byte          ' zhlt fr 100ms
Dim Lcounter As Byte          ' Tonausgabecounter
Dim Freq As Byte              ' Reloadwert fr Tonausgabefrequenz
Dim A As Byte                 ' aktuelles Datenbyte
Dim Dauer As Byte             ' extrahierte Tondauer
Dim Ton As Byte               ' extrahierte Tonhhe
Dim Zeit As Byte              ' Zhler fr Tondauer
Dim Adresse As Integer        ' Zeiger auf Note
Dim Adr_temp As Integer       ' Temp-Zeiger auf Note
Dim Led As Bit                ' LED-Buffer
Dim Sp As Bit                 ' LP-Pin-Buffer
Dim Vip As Bit                ' VIP-Kennzeichnung
Dim Run As Bit                ' Flag zum Start

'****************************************************************************

   Reset Run                  ' Halt
   Reset Vip                  ' kein VIP
   Freq = 255                 ' kein Ton
   Set Led_play               ' Play aus
   Reset Led_stop             ' Stop an
   Reset Led_sperre           ' Sperre an
   Set Speaker                ' LP stromlos
   Sperre = 0                 ' Sperre aus
   Scounter = Reload          ' 100 ms-Zhler auf Startwert
   Adresse = Loadlabel(songs) ' Zeiger auf Tebellenanfang

Main:                         ' Hauptschleife
   While Run = 0              ' Warten auf Run-Flag
   Wend                       ' wird nur durch INT0/1 gesetzt !
   Reset Run                  ' gleich wieder aus...
   Disable Int0               ' Pegelwechsel auf INT0 darf nicht mehr stren
   Disable Int1               ' Pegelwechsel auf INT1 darf nicht mehr stren
   Stop Watchdog              ' Watchdog anhalten
   Reset Led_play             ' Play an
   Set Led_stop               ' Stop aus
   Adr_temp = Adresse         ' Adresse fr alle Flle retten
   If Vip = 1 Then Adresse = Loadlabel(vip)       ' bei VIP Zeiger auf VIP-Lied

   '--------------------------------------------------------------------------
   Do                         ' Schleife Lied abspielen
     A = Cpeek(adresse)       ' Datenbyte lesen
     If Adresse < Loadlabel(tab_end) Then Adresse = Adresse + 1       ' Zeiger++
     Ton = A And &B0000_1111  ' Tonhhe holen
     Dauer = A And &B0111_0000       ' Tondauer abschneiden...
     Shift Dauer , Right , 4  ' ...und durch 16
     Gosub Tonausgabe         ' Tonausgabe
   Loop Until A > 127         ' solange bis Bit .7 = 1, also Liedende
   '--------------------------------------------------------------------------

   If Vip = 0 Then            ' wenn kein VIP, dann...
     A = Cpeek(adresse)       ' nach dem nchsten Byte schauen
     If A = Tabende Then Adresse = Loadlabel(songs)       ' Tabellenende ?
     Sperre = Sperrdauer      ' Sperre Setzen
     Disable Int1             ' INT1 aus
     Reset Led_sperre         ' LED Sperre an
   Else                       ' bei VIP
     Adresse = Adr_temp       ' Zeiger wieder auf alten Song und...
     If Sperre = 0 Then Enable Int1       ' ... INT1 freigeben falls Sperre = 0
   End If

   Set Led_play               ' Play aus
   Reset Led_stop             ' Stop an
   Enable Int0                ' INT0 an
   Start Watchdog             ' Wachhund scharf
   Reset Run                  ' Run nochmal stoppen
   Goto Main                  ' und wieder von vorn...
End

'****************************************************************************
Isr_int1:                     ' normaler Klingeleingang
'****************************************************************************

  Reset Vip                   ' kein VIP
  Set Run                     ' Start ...

Return

'****************************************************************************
Isr_int0:                     ' VIP-Klingel (Gartentor)
'****************************************************************************

  Set Vip                     ' VIP
  Set Run                     ' Start ...

Return

'****************************************************************************
Tim1_isr:                     ' Timer1-ISR
'****************************************************************************

  If Scounter > 0 Then        ' Per Zhlvariable eine 100ms-Funktion machen
    Scounter = Scounter - 1
  Else
    Scounter = Reload         ' Reloadwert fr 100ms
    Gosub 100ms               ' Funktion 100ms
  End If

  Reset Watchdog              ' Wachhund rcksetzen

Return

'****************************************************************************
100ms:
'****************************************************************************

   ' --- Zhler fr Tondauer handeln ----------------------
   If Zeit > 0 Then
     Zeit = Zeit - 1
   Else
     Disable Timer0           ' wenn abgelaufen dann Ton aus durch Timer0 aus
   End If

   ' --- Zhler fr Sperrzeit von INT1 handeln ------------
   If Sperre > 0 Then
     Sperre = Sperre - 1
   Else
     Set Led_sperre           ' LED Sperre aus
     Enable Int1              ' INT1 wieder freigeben
   End If

   Gosub Blink_led            ' Takt-LED blinken lassen

Return

'****************************************************************************
Blink_led:                    ' LED blinken lassen
'****************************************************************************

    Led = Led Xor 1           ' LED = NOT LED
    Led_takt = Led            ' Port = LED

Return

'****************************************************************************
Tim0_isr:                     ' Timer0-ISR
'****************************************************************************

  If Lcounter > 0 Then
    Lcounter = Lcounter - 1
  Else
    Lcounter = Freq           ' Reloadwert
    Gosub Lp_out              ' Funktion Lp_out
  End If

Return

'****************************************************************************
Lp_out:                       ' Timer1-ISR
'****************************************************************************

    Sp = Sp Xor 1             ' Bit invertieren
    If Freq = 255 Then Set Speaker Else Speaker = Sp       ' Ausgabe, wenn
                                                           ' keine Pause
Return

'****************************************************************************
Tonausgabe:
'****************************************************************************

     Freq = Lookup(ton , Tab_ton)       ' Reloadwert fr Frequenz holen

     Zeit = Dauer + 1         ' Tondauer in den Counter
     Stop Timer1              ' Stop TIMER1, um...
     Timer1 = 0               ' ...Timer1 auf 0 zurck zu setzen, damit...
     Start Timer1             ' ...alle Achtelnoten gleichlang sind -> Start

     Enable Timer0            ' Timer 0 und damit Tonerzeugung freigeben

     While Zeit > 0           ' warten, bis der Achtelnotenzhler = 0
     Wend

     Set Speaker              ' Lautsprecher stromlos machen

Return

'****************************************************************************
' Daten
'****************************************************************************
'
Tab_ton:
'
Data 255 , 80 , 76 , 72 , 68 , 64 , 60 , 57 , 54 , 51 , 48 , 45 , 43 , 40 , 38 , 36
'
'Aufbau eines Liedbytes:
'Bit
'7  6  5  4  3  2  1  0
'|  |__|__|  |__|__|__|_ Tonhhe ( 1..15 (G..B') incl. aller Halbtonschritte
'|     |                 wenn 0, kein Ton sondern Pause
'|     |
'|     |________________ Tonlnge in Achtelnoten
'|
'|______________________ Stop-Bit
'
'Grundidee und Tonformat von Steffen Lehmann "Eine Melodieklingel mit vielen Melodien"
'[eine Schaltung mit einem Z80]
'Zeitschrift "Funkamateur" 4/86 S. 203
'
Songs:

' -- Titel #1 -----------------------------------------------------------------
Data &H03 , &H00 , &H05 , &H00 , &H07 , &H00 , &H08 , &H00 , &H0A , &H00 , &H0C
Data &H00 , &H3A , &H08 , &H00 , &H05 , &H00 , &H3E , &H0A , &H00 , &H07 , &H00
Data &HAF

' -- Titel #2 -----------------------------------------------------------------
Data &H35 , &H00 , &H2A , &H00 , &H02 , &H05 , &H10 , &H05 , &H10 , &H85

' -- Titel #3 -----------------------------------------------------------------
Data &H03 , &H00 , &H05 , &H00 , &H37 , &H3A , &H0E , &H20 , &H1C , &H10
Data &H2C , &H00 , &HA7

' -- Titel #4 -----------------------------------------------------------------
Data &H47 , &H00 , &H06 , &H00 , &H07 , &H00 , &H0F , &H00 , &H07 , &H00 , &H0E
Data &H00 , &H0C , &H20 , &H0C , &H20 , &H9C

' -- Titel #5 -----------------------------------------------------------------
Data &H0A , &H00 , &H2F , &H10 , &H1E , &H10 , &H0C , &H0A , &H10 , &HA7

' -- Titel #6 -----------------------------------------------------------------
Data &H53 , &H17 , &H3A , &H3F , &H3C , &H1F , &H1C , &HBA

' -- Titel #7 -----------------------------------------------------------------
Data &H13 , &H20 , &H15 , &H20 , &H17 , &H00 , &H1A , &H1C , &H00 , &H1A , &H1F
Data &H20 , &H1C , &H20 , &H1A , &HB7

' -- Titel #8 -----------------------------------------------------------------
Data &H17 , &H18 , &H3A , &H27 , &H00 , &H27 , &H00 , &H37 , &H95

' -- Titel #9 -----------------------------------------------------------------
Data &H33 , &H08 , &H00 , &H0A , &H00 , &H3C , &H3F , &H3C , &H3A , &HB8

' -- Titel #10 ----------------------------------------------------------------
Data &H48 , &H00 , &H0A , &H00 , &H08 , &H00 , &H06 , &H00 , &H25 , &H00 , &H21
Data &H00 , &HB1

' -- Titel #11 ----------------------------------------------------------------
Data &H45 , &H00 , &H03 , &H00 , &H02 , &H00 , &H05 , &H00 , &H0A , &H00 , &H0C
Data &H00 , &H5E , &H10 , &HBA

' -- Titel #12 ----------------------------------------------------------------
Data &H0A , &H00 , &H08 , &H00 , &H0A , &H00 , &H08 , &H00 , &H07 , &H20 , &HB3

' -- Titel #13 ----------------------------------------------------------------
Data &H03 , &H00 , &H03 , &H00 , &H25 , &H00 , &H23 , &H00 , &H28 , &H00 , &H47
Data &H20 , &H03 , &H00 , &H03 , &H00 , &H25 , &H00 , &H23 , &H00 , &H2A , &H00
Data &HC8

' -- Titel #14 ----------------------------------------------------------------
Data &H46 , &H00 , &H14 , &H13 , &H14 , &H36 , &H3F , &H3B , &HA6

' -- Titel #15 ----------------------------------------------------------------
Data &H15 , &H12 , &H50 , &H12 , &H23 , &H15 , &H0E , &H20 , &H0E , &H20 , &HBA

' -- Titel #16 ----------------------------------------------------------------
Data &H28 , &H00 , &H03 , &H00 , &H23 , &H10 , &H38 , &H00 , &H25 , &H00 , &H05
Data &H00 , &H25 , &H40 , &H27 , &H00 , &H08 , &H00 , &H2A , &H10 , &H27 , &H10
Data &H28 , &H00 , &H0C , &H00 , &HB8

' -- Titel #17 ----------------------------------------------------------------
Data &H4A , &H00 , &H07 , &H10 , &H0A , &H10 , &H07 , &H10 , &H0A , &H10 , &H08
Data &H10 , &HA8

' -- Titel #18 ----------------------------------------------------------------
Data &H0C , &H00 , &H0B , &H00 , &H0C , &H20 , &H0C , &H00 , &H0B , &H00 , &H0C
Data &H20 , &H0C , &H00 , &H0B , &H00 , &H0C , &H20 , &H0A , &H20 , &H98

' -- Titel #19 ----------------------------------------------------------------
Data &H03 , &H00 , &H03 , &H00 , &H28 , &H00 , &H2C , &H00 , &H08 , &H00 , &H08
Data &H00 , &H2A , &H00 , &H2D , &H00 , &H03 , &H00 , &H07 , &H00 , &H3A , &H00
Data &H0C , &H00 , &H2A , &H00 , &HA8

' -- Titel #20 ----------------------------------------------------------------
Data &H03 , &H00 , &H05 , &H00 , &H27 , &H00 , &H07 , &H00 , &H0A , &H00 , &H28
Data &H00 , &H08 , &H00 , &H0C , &H00 , &H1A , &H00 , &H0C , &H0A , &H00 , &H08
Data &H00 , &HA7

' -- Titel #21 ----------------------------------------------------------------
Data &H21 , &H00 , &H46 , &H00 , &H08 , &H00 , &H0B , &H00 , &H0A , &H00 , &H08
Data &H00 , &H2D , &H00 , &HAD

' -- Titel #22 ----------------------------------------------------------------
Data &H28 , &H00 , &H4D , &H00 , &H08 , &H00 , &H25 , &H00 , &H26 , &H00 , &H48
Data &H00 , &H0A , &H00 , &HA8

' -- Titel #23 ----------------------------------------------------------------
Data &H23 , &H00 , &H4F , &H00 , &H0E , &H00 , &H2F , &H00 , &H2C , &H00 , &H4D
Data &H00 , &H0C , &H00 , &H2D , &H00 , &H27 , &H00 , &H0A , &H00 , &H18 , &H6A
Data &H00 , &H6A , &H00 , &H0A , &H00 , &H3C , &H30 , &H0A , &H00 , &H2C , &H00
Data &H0A , &H00 , &H0C , &H00 , &H2A , &H00 , &H09 , &H00 , &HB8

' -- Titel #24 ----------------------------------------------------------------
Data &H0C , &H20 , &H2A , &H20 , &H07 , &H00 , &H05 , &H00 , &H03 , &H00 , &H2C
Data &H00 , &H2B , &H00 , &HAC

' -- Titel #25 ----------------------------------------------------------------
Data &H07 , &H00 , &H05 , &H00 , &H03 , &H00 , &H05 , &H00 , &H07 , &H00 , &H05
Data &H00 , &H03 , &H00 , &H05 , &H00 , &H27 , &H00 , &H0C , &H20 , &H27 , &H00
Data &H8C

' -- Titel #26 ----------------------------------------------------------------
Data &H03 , &H00 , &H05 , &H00 , &H27 , &H00 , &H27 , &H00 , &H08 , &H00 , &H05
Data &H00 , &H1C , &H0A , &H00 , &HAA

Vip:
' -- Titel #27 ----------------------------------------------------------------
Data &H23 , &H00 , &H03 , &H00 , &H07 , &H00 , &H2A , &H00 , &H2A , &H00 , &H2A
Data &H00 , &H0C , &H00 , &H0A , &H00 , &H27 , &H00 , &HA3 ,

' -- Titel #28 ----------------------------------------------------------------
Data &H3F , &H3E , &H3C , &H3A , &H3C , &H18 , &H17 , &H25 , &H00 , &HA3

' -- Titel #29 ----------------------------------------------------------------
Data &H00 , &H23 , &H00 , &H48 , &H00 , &H03 , &H00 , &H28 , &H00 , &H0C , &H00
Data &H0C , &H00 , &H68 , &H00 , &H23 , &H00 , &H08 , &H00 , &H0C , &H00 , &H2A
Data &H00 , &H23 , &H00 , &H23 , &H00 , &H05 , &H00 , &H07 , &H00 , &HE8

' -- Titel #30 ----------------------------------------------------------------
Data &H03 , &H00 , &H23 , &H00 , &H07 , &H00 , &H2A , &H00 , &H0F , &H00 , &H4A
Data &H00 , &H27 , &H00 , &H03 , &H00 , &H25 , &H00 , &H05 , &H00 , &H15 , &H07
Data &H00 , &H05 , &H00 , &HC3

' -- Titel #31 ----------------------------------------------------------------
Data &H6F , &H00 , &H2C , &H00 , &H28 , &H00 , &H2C , &H00 , &H2F , &H00 , &H3F
Data &H2D , &H00 , &H2A , &H00 , &H30 , &H28 , &H00 , &H08 , &H00 , &H08 , &H00
Data &H28 , &H00 , &H28 , &H00 , &H28 , &H00 , &H08 , &H00 , &H08 , &H00 , &H2A
Data &H00 , &H07 , &H00 , &H05 , &H00 , &H23 , &H00 , &H30 , &H6F , &H00 , &H2C
Data &H00 , &H28 , &H00 , &H2C , &H00 , &H2F , &H00 , &H3F , &H2D , &H00 , &HAA

' -- Titel #32 ----------------------------------------------------------------
Data &H00 , &H2A , &H00 , &H2E , &H00 , &H2C , &H00 , &H10 , &H05 , &H00 , &H07
Data &H00 , &H05 , &H00 , &H07 , &H00 , &H09 , &H00 , &HAA

' -- Titel #33 ----------------------------------------------------------------
Data &H03 , &H00 , &H03 , &H00 , &H07 , &H00 , &H2A , &H00 , &H2A , &H00 , &H2C
Data &H00 , &H2A , &H00 , &H10 , &H08 , &H00 , &H07 , &H00 , &H05 , &H00 , &H13
Data &H07 , &H00 , &H1A , &H07 , &H00 , &HE5

' -- Titel #34 ----------------------------------------------------------------
Data &H25 , &H00 , &H4A , &H00 , &H0C , &H00 , &H2C , &H00 , &H2C , &H00 , &H6A
Data &H00 , &H29 , &H00 , &H2A , &H00 , &H1C , &H0E , &H00 , &H2F , &H00 , &H1E
Data &H0C , &H00 , &H2A , &H00 , &HEC

' -- Titel #35 ----------------------------------------------------------------
Data &H03 , &H00 , &H07 , &H00 , &H2A , &H00 , &H07 , &H00 , &H05 , &H00 , &H23
Data &H00 , &H25 , &H00 , &H25 , &H00 , &H23 , &H00 , &H10 , &H0A , &H00 , &H0C
Data &H00 , &H0A , &H00 , &H0C , &H00 , &H0E , &H00 , &H2F , &H00 , &H2E , &H00
Data &H2C , &H00 , &HAA

' -- Titel #36 ----------------------------------------------------------------
Data &H26 , &H00 , &H2A , &H00 , &H2D , &H00 , &H28 , &H00 , &H08 , &H00 , &H05
Data &H00 , &H21 , &H00 , &H26 , &H00 , &H2A , &H00 , &H2D , &H00 , &HE8

' -- Titel #37 ----------------------------------------------------------------
Data &H03 , &H00 , &H07 , &H00 , &H07 , &H00 , &H2A , &H00 , &H2A , &H00 , &H27
Data &H00 , &H23 , &H00 , &H05 , &H00 , &H03 , &H00 , &H05 , &H00 , &H07 , &H00
Data &H25 , &H00 , &H03 , &H00 , &H07 , &H00 , &H2A , &H00 , &H2A , &H00 , &H27
Data &H00 , &H23 , &H00 , &HE5

' -- Titel #38 ----------------------------------------------------------------
Data &H06 , &H00 , &H06 , &H00 , &H2B , &H00 , &H2B , &H00 , &H0F , &H00 , &H0B
Data &H00 , &HE6

' -- Titel #39 ----------------------------------------------------------------
Data &H12 , &H05 , &H00 , &H1A , &H02 , &H00 , &H25 , &H00 , &H23 , &H00 , &H27
Data &H00 , &H27 , &H00 , &H15 , &H09 , &H00 , &H1C , &H0F , &H00 , &H1E , &H0C
Data &H00 , &HEA

' -- Titel #40 ----------------------------------------------------------------
Data &H24 , &H00 , &H49 , &H00 , &H08 , &H00 , &H26 , &H00 , &H24 , &H00 , &H46
Data &H00 , &H04 , &H00 , &HA1 , &H23 , &H00 , &H48 , &H00 , &H08 , &H00 , &H28
Data &H00 , &H28 , &H00 , &H23 , &H00 , &H25 , &H00 , &H63 , &H00 , &H68 , &H00
Data &H2F , &H00 , &H2F , &H00 , &HEC

' -- Titel #41 ----------------------------------------------------------------
Data &H21 , &H00 , &H46 , &H00 , &H08 , &H00 , &H2A , &H00 , &H1B , &H0F , &H00
Data &H6D , &H00 , &H30 , &H16 , &H0A , &H00 , &H2D , &H00 , &H2D , &H00 , &H2B
Data &H00 , &H1D , &H0B , &H00 , &HEA

' -- Titel #42 ----------------------------------------------------------------
Data &H2B , &H00 , &H0D , &H00 , &H0D , &H00 , &H0D , &H00 , &H0D , &H00 , &H0D
Data &H00 , &H0D , &H00 , &H0D , &H00 , &H0D , &H00 , &H2D , &H00 , &H1C , &H0A
Data &H00 , &H28 , &H00 , &H30 , &H2A , &H00 , &H0A , &H00 , &H0A , &H00 , &H2C
Data &H00 , &H0C , &H00 , &H0C , &H00 , &H0D , &H00 , &H0D , &H00 , &H8B

' -- Titel #43 ----------------------------------------------------------------
Data &H26 , &H00 , &H28 , &H00 , &H26 , &H00 , &H2B , &H00 , &H2A , &H00 , &H68
Data &H00 , &H26 , &H00 , &H2A , &H00 , &H2A , &H00 , &H2A , &H00 , &H2F , &H00
Data &H2D , &H00 , &H2D , &H00 , &H6B , &H00 , &H2A , &H00 , &H2A , &H00 , &H2A
Data &H00 , &H2B , &H00 , &H2A , &H00 , &HE8

' -- Titel #44 ----------------------------------------------------------------
Data &H23 , &H00 , &H48 , &H00 , &H08 , &H00 , &H28 , &H00 , &H0C , &H00 , &H0A
Data &H00 , &H38 , &H25 , &H00 , &H23 , &H00 , &H28 , &H00 , &H25 , &H00 , &H21
Data &H00 , &H03 , &H00 , &H07 , &H00 , &H2A , &H00 , &HE8

' -- Titel #45 ----------------------------------------------------------------
Data &H23 , &H00 , &H28 , &H00 , &H28 , &H00 , &H2A , &H00 , &H2F , &H00 , &H6C
Data &H00 , &H2C , &H00 , &H2D , &H00 , &H2A , &H00 , &H28 , &H00 , &H2A , &H00
Data &H27 , &H00 , &HE8

' -- Titel #46 ----------------------------------------------------------------
Data &H05 , &H00 , &H28 , &H00 , &H05 , &H00 , &H06 , &H00 , &H05 , &H00 , &H03
Data &H00 , &H21 , &H00 , &H05 , &H00 , &H05 , &H00 , &H03 , &H00 , &H01 , &H00
Data &H23 , &H00 , &H06 , &H00 , &H06 , &H00 , &H05 , &H00 , &H03 , &H00 , &H25
Data &H00 , &H08 , &H00 , &HAD

' -- Titel #47 ----------------------------------------------------------------
Data &H6C , &H00 , &H6A , &H00 , &H2D , &H00 , &H17 , &H05 , &H00 , &H23 , &H00
Data &H23 , &H00 , &H28 , &H00 , &H28 , &H00 , &H2A , &H00 , &H2A , &H00 , &HEC

' -- Titel #48 ----------------------------------------------------------------
Data &H2D , &H00 , &H2D , &H00 , &H2D , &H00 , &H28 , &H00 , &H2C , &H00 , &H0D
Data &H00 , &H2A , &H00 , &H68 , &H00 , &H2D , &H00 , &H2C , &H00 , &H2A , &H00
Data &H28 , &H00 , &H2A , &H00 , &H16 , &H15 , &H23 , &H00 , &HE1

' -- Titel #49 ----------------------------------------------------------------
Data &H01 , &H00 , &H06 , &H00 , &H08 , &H00 , &H0A , &H00 , &H0B , &H00 , &H2D
Data &H00 , &H0F , &H00 , &H0B , &H00 , &H0A , &H00 , &H10 , &H08 , &H00 , &H10
Data &HA6

' -- Titel #50 ----------------------------------------------------------------
Data &H13 , &H07 , &H00 , &H2A , &H00 , &H2A , &H00 , &H27 , &H00 , &H23 , &H00
Data &H15 , &H03 , &H00 , &H15 , &H07 , &H00 , &H25 , &H00 , &H13 , &H07 , &H00
Data &H2A , &H00 , &H2A , &H00 , &H27 , &H00 , &H23 , &H00 , &HE5

' -- Titel #51 ----------------------------------------------------------------
Data &H03 , &H00 , &H28 , &H00 , &H08 , &H00 , &H18 , &H07 , &H00 , &H08 , &H00
Data &H2A , &H00 , &H0A , &H00 , &H2A , &H00 , &H0A , &H00 , &H2C , &H00 , &H0C
Data &H00 , &H1F , &H0D , &H00 , &H0A , &H00 , &HC8

' -- Titel #52 ----------------------------------------------------------------
Data &H0C , &H00 , &H0F , &H00 , &H0C , &H00 , &H0F , &H00 , &H0C , &H00 , &H0D
Data &H00 , &H0A , &H00 , &H0D , &H00 , &H0A , &H00 , &H0C , &H00 , &H08 , &H00
Data &H0F , &H00 , &H0C , &H00 , &H0A , &H00 , &H0F , &H00 ,

' -- Titel #53 ----------------------------------------------------------------
Data &H8F , &H23 , &H00 , &H2C , &H00 , &H0C , &H00 , &H0C , &H00 , &H2C , &H00
Data &H2A , &H00 , &H68 , &H00 , &H28 , &H00 , &H23 , &H00 , &H2D , &H00 , &H0D
Data &H00 , &H0D , &H00 , &H0D , &H00 , &H0C , &H00 , &H0F , &H00 , &H0C , &H00
Data &HEA

' -- Titel #54 ----------------------------------------------------------------
Data &H28 , &H00 , &H2D , &H00 , &H08 , &H00 , &H05 , &H00 , &H28 , &H00 , &H06
Data &H00 , &H03 , &H00 , &H68 , &H00 , &H25 , &H00 , &H10 , &H08 , &H00 , &H28
Data &H00 , &H0A , &H00 , &H08 , &H00 , &H26 , &H00 , &H05 , &H00 , &H03 , &H00
Data &HE1

' -- Titel #55 ----------------------------------------------------------------
Data &H46 , &H00 , &H17 , &H06 , &H00 , &H07 , &H00 , &H39 , &H0E , &H00 , &H02
Data &H00 , &H10 , &H42 , &H00 , &H17 , &H02 , &H00 , &H04 , &H00 , &H16 , &H07
Data &H00 , &H06 , &H00 , &HA4

' -- Titel #56 ----------------------------------------------------------------
Data &H06 , &H00 , &H06 , &H00 , &H49 , &H00 , &H06 , &H00 , &H26 , &H00 , &H29
Data &H00 , &H30 , &H06 , &H00 , &H09 , &H00 , &H2E , &H00 , &H4D , &H00 , &H0B
Data &H00 , &H3B , &H29 , &H00 , &H04 , &H00 , &H06 , &H00 , &H27 , &H00 , &H24
Data &H00 , &H04 , &H00 , &H06 , &H00 , &H27 , &H00 , &H30 , &H04 , &H00 , &H07
Data &H00 , &H0D , &H00 , &H0B , &H00 , &H29 , &H00 , &H2D , &H00 , &HAE

' -- Titel #57 ----------------------------------------------------------------
Data &H01 , &H00 , &H05 , &H00 , &H48 , &H00 , &H08 , &H00 , &H08 , &H00 , &H0A
Data &H00 , &H0C , &H00 , &H6D , &H00 , &H28 , &H00 , &H0A , &H00 , &H08 , &H00
Data &H48 , &H00 , &H06 , &H00 , &H06 , &H00 , &H0A , &H00 , &H06 , &H00 , &HE5

' -- Titel #58 ----------------------------------------------------------------
Data &H03 , &H00 , &H05 , &H00 , &H07 , &H00 , &H08 , &H00 , &H0A , &H00 , &H0C
Data &H00 , &H2A , &H00 , &H08 , &H00 , &H05 , &H00 , &H2E , &H00 , &H0A , &H00
Data &H07 , &H00 , &HAF

' -- Titel #59 ----------------------------------------------------------------
Data &H03 , &H00 , &H07 , &H00 , &H4A , &H00 , &H0F , &H00 , &H0A , &H00 , &H07
Data &H00 , &H08 , &H00 , &H05 , &H00 , &H67 , &H00 , &H25 , &H00 , &H25 , &H00
Data &H27 , &H00 , &H07 , &H00 , &H0A , &H00 , &H28 , &H00 , &H08 , &H00 , &H0C
Data &H00 , &HEA

' -- Titel #60 ----------------------------------------------------------------
Data &H03 , &H00 , &H07 , &H00 , &H4A , &H00 , &H0C , &H00 , &H2A , &H00 , &H28
Data &H00 , &H57 , &H05 , &H00 , &H23 , &H00 , &H2A , &H00 , &H2C , &H00 , &H2A
Data &H00 , &H28 , &H00 , &H27 , &H00 , &HE5

' -- Titel #61 ----------------------------------------------------------------
Data &H06 , &H00 , &H26 , &H00 , &H06 , &H00 , &H26 , &H00 , &H06 , &H00 , &H46
Data &H00 , &H23 , &H00 , &H06 , &H00 , &H2B , &H00 , &H0B , &H00 , &H2B , &H00
Data &H0B , &H00 , &H3F , &H0D , &H00 , &H1B , &H0A , &H00 , &H08 , &H00 , &H26
Data &H00 , &H06 , &H00 , &H16 , &H08 , &H00 , &H0A , &H00 , &HEB

' -- Titel #62 ----------------------------------------------------------------
Data &H0E , &H00 , &H0C , &H00 , &H2A , &H00 , &H25 , &H00 , &H25 , &H00 , &H2A
Data &H00 , &H27 , &H00 , &H27 , &H00 , &H27 , &H00 , &H10 , &H0A , &H00 , &H29
Data &H00 , &H29 , &H00 , &H29 , &H00 , &H27 , &H00 , &HE5

' -- Titel #63 ----------------------------------------------------------------
Data &H01 , &H00 , &H2A , &H00 , &H0A , &H00 , &H1A , &H08 , &H00 , &H0A , &H00
Data &H2B , &H00 , &H08 , &H00 , &H25 , &H00 , &H01 , &H00 , &H26 , &H00 , &H06
Data &H00 , &H16 , &H05 , &H00 , &H06 , &H00 , &HE8

' -- Titel #64 ----------------------------------------------------------------
Data &H03 , &H00 , &H08 , &H00 , &H03 , &H00 , &H28 , &H00 , &H2C , &H00 , &H0A
Data &H00 , &H0A , &H00 , &H08 , &H00 , &H03 , &H00 , &H08 , &H00 , &H03 , &H00
Data &H28 , &H00 , &H2C , &H00 , &H0F , &H00 , &H0F , &H00 , &H0C , &H00 , &H0A
Data &H00 , &H08 , &H00 , &H0A , &H00 , &H1C , &H1F , &H0D , &H00 , &H0C , &H00
Data &H0A , &H00 , &H0A , &H00 , &HA8

' -- Titel #65 ----------------------------------------------------------------
Data &H21 , &H00 , &H26 , &H00 , &H06 , &H00 , &H06 , &H00 , &H2A , &H00 , &H0A
Data &H00 , &H0A , &H00 , &H6F , &H00 , &H6D , &H00 , &H70 , &H6D , &H00 , &H4D
Data &H00 , &H0D , &H00 , &HED

' -- Titel #66 ----------------------------------------------------------------
Data &H21 , &H00 , &H26 , &H00 , &H26 , &H00 , &H08 , &H00 , &H08 , &H00 , &H2A
Data &H00 , &H2A , &H00 , &H10 , &H0B , &H00 , &H2D , &H00 , &H1F , &H0D , &H00
Data &H1B , &H0A , &H00 , &H3A , &HA8

' -- Titel #67 ----------------------------------------------------------------
Data &H03 , &H00 , &H03 , &H00 , &H28 , &H00 , &H2C , &H00 , &H0A , &H00 , &H08
Data &H00 , &H48 , &H00 , &H03 , &H00 , &H03 , &H00 , &H03 , &H00 , &H28 , &H00
Data &H2C , &H00 , &H0A , &H00 , &H08 , &H00 ,

' -- Titel #68 ----------------------------------------------------------------
Data &HCA , &H2C , &H00 , &H0C , &H00 , &H0F , &H00 , &H6A , &H00 , &H2C , &H00
Data &H0C , &H00 , &H0F , &H00 , &H6A , &H00 , &H2D , &H00 , &H2D , &H00 , &H2C
Data &H00 , &H2F , &H00 , &H6A , &H00 , &HA8

' -- Ende Tabelle -------------------------------------------------------------
Data &HFF
Tab_end: